pysmug.smugsync.SmugSync

Package pysmug :: Module smugsync :: Class SmugSync |
[hide private]
[frames] | no frames]

# Class SmugSync

source code

Synchronize a local directory with SmugMug albums.

Instance Methods | [hide private]
__init__(self, smugmug=None) | source code
filesystem(self, directory) Scan the file system to produce a ((subcategory, title), filename) generator. | source code
smugmug(self, category) Scan the album tree to produce a ((subcategory, title), filename) generator. | source code

Method Details | [hide private]

### filesystem(self, directory) | source code
Scan the file system to produce a ((subcategory, title), filename) generator. Parameters: `directory` - the root of the directory tree

### smugmug(self, category) | source code
Scan the album tree to produce a ((subcategory, title), filename) generator. Parameters: `category` - the root category for backup albums